@@ -208,6 +208,8 @@ extern globus_bool_t                    globus_i_gssapi_active;
                     _function_name_))
 
 extern int                              globus_i_gsi_gssapi_force_tls;
+extern const char *                     globus_i_gsi_gssapi_cipher_list;
+extern globus_bool_t                    globus_i_gsi_gssapi_server_cipher_order;
 
 typedef enum
 {
